==> release-1.54.0.zip: documentation/content/mentorship.md <==
---
title: Mentorships
---

The Jaeger project regularly participates in mentorship programs via CNCF, such as [Outreachy](https://www.outreachy.org/), [Google Summer of Code](https://summerofcode.withgoogle.com/), and [LFX Mentorship](https://mentorship.lfx.linuxfoundation.org/). As a mentee, you will have the opportunity to contribute to an open-source project while working under the guidance of an experienced mentor who is an active contributor to the project and open-source community. The mentees receive an internship stipend.

See also:
  * [For mentees](../mentorship-for-mentees/)
  * [For mentors](../mentorship-for-mentors/)

## LFS Mentorship March-May 2024 (Term 1)

{{< warning >}}
Mentee applications are open between Monday Jan 29 - Tues Feb 13, 5:00 PM PDT.
{{< /warning >}}

* See [this issue](https://github.com/jaegertracing/jaeger/issues/5084) for project details.

## LFX Mentorship Sep-Nov 2023

* [Ansh Goyal](https://github.com/anshgoyalevil) -- [Upgrade Jaeger UI to the latest version of React.js](https://github.com/jaegertracing/jaeger-ui/issues/998)
* [Prathamesh Mutkure](https://github.com/prathamesh-mutkure) -- [Combine three distinct graph views in Jaeger UI into one](https://github.com/jaegertracing/jaeger-ui/issues/1466)
* [Yashwanth Reddy](https://github.com/pmuls99) -- [Build official support in Jaeger for Elasticsearch 8](https://github.com/jaegertracing/jaeger/issues/4600)

## LFX Mentorship Jun-Aug 2023

* [Afzal Ansari](https://github.com/afzal442) -- [Upgrade internal use of tracing to OpenTelemetry](https://github.com/jaegertracing/jaeger/issues/3381)
* [GLVS Kiriti](https://github.com/GLVSKiriti) -- [Visualize Critical Path of a trace](https://github.com/jaegertracing/jaeger-ui/issues/1288)

## Google Summer of Code 2023

* [Ha Anh Vu](https://github.com/haanhvu) -- [ClickHouse as a core storage backend](https://github.com/jaegertracing/jaeger/issues/4196)

## Outreachy Dec'20 - Mar'21

[Ashmita Bohara](https://github.com/Ashmita152)

## Outreachy Dec'18 - Mar'19

[Gaby Soria](https://github.com/gsoria)

## Outreachy May'18 - Aug'18

[Prakriti Bansal](https://github.com/PikBot)

## Outreachy Dec'17 - Mar'18

[Kara de la Marck](https://github.com/MarckK)

==> release-1.55.0.zip: documentation/content/mentorship.md <==
---
title: Mentorships
---

The Jaeger project regularly participates in mentorship programs via CNCF, such as [Outreachy](https://www.outreachy.org/), [Google Summer of Code](https://summerofcode.withgoogle.com/), and [LFX Mentorship](https://mentorship.lfx.linuxfoundation.org/). As a mentee, you will have the opportunity to contribute to an open-source project while working under the guidance of an experienced mentor who is an active contributor to the project and open-source community. The mentees receive an internship stipend.

See also:
  * [For mentees](../mentorship-for-mentees/)
  * [For mentors](../mentorship-for-mentors/)

## LFX Mentorship March-May 2024 (Term 1)

* [Harshvir Potpose](https://github.com/akagami-harsh) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)
* [James Ryans](https://github.com/james-ryans) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)
* [Pushkar Mishra](https://github.com/Pushkarm029) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)

## LFX Mentorship Sep-Nov 2023

* [Ansh Goyal](https://github.com/anshgoyalevil) -- [Upgrade Jaeger UI to the latest version of React.js](https://github.com/jaegertracing/jaeger-ui/issues/998)
* [Prathamesh Mutkure](https://github.com/prathamesh-mutkure) -- [Combine three distinct graph views in Jaeger UI into one](https://github.com/jaegertracing/jaeger-ui/issues/1466)
* [Yashwanth Reddy](https://github.com/pmuls99) -- [Build official support in Jaeger for Elasticsearch 8](https://github.com/jaegertracing/jaeger/issues/4600)

## LFX Mentorship Jun-Aug 2023

* [Afzal Ansari](https://github.com/afzal442) -- [Upgrade internal use of tracing to OpenTelemetry](https://github.com/jaegertracing/jaeger/issues/3381)
* [GLVS Kiriti](https://github.com/GLVSKiriti) -- [Visualize Critical Path of a trace](https://github.com/jaegertracing/jaeger-ui/issues/1288)

## Google Summer of Code 2023

* [Ha Anh Vu](https://github.com/haanhvu) -- [ClickHouse as a core storage backend](https://github.com/jaegertracing/jaeger/issues/4196)

## Outreachy Dec'20 - Mar'21

[Ashmita Bohara](https://github.com/Ashmita152)

## Outreachy Dec'18 - Mar'19

[Gaby Soria](https://github.com/gsoria)

## Outreachy May'18 - Aug'18

[Prakriti Bansal](https://github.com/PikBot)

## Outreachy Dec'17 - Mar'18

[Kara de la Marck](https://github.com/MarckK)
